==> fetch.php?media=harmonics%3Aharmonics_2.1.0.zip: HARMONICS2.1.0/HARMONICS/observationdatamanagementdbmainwindow.h <==


//observationdatamanagementdbmainwindow.h
//(c) 2018 The University of Aizu
//This software is released under the GNU General Public License.


#ifndef OBSERVATIONDATAMANAGEMENTDBMAINWINDOW_H
#define OBSERVATIONDATAMANAGEMENTDBMAINWINDOW_H

#include <QMainWindow>
#include <QSqlDatabase>
#include <QSqlDriver>
#include <QSqlQuery>
#include <QSqlError>
#include <QDebug>
#include <QDir>
#include <QFileDialog>
#include <QStandardItemModel>
#include <QAbstractItemModel>
#include <QSqlDatabase>
#include <QSqlQuery>
#include <QSql>
#include <QVector>
#include <QVector2D>
#include "SpiceUsr.h"
#include "SpiceDLA.h"
#include "SpiceDSK.h"
#include <QMenu>
#include <QMessageBox>
#include <QtGui>
#include <fitsio.h>
#include <CCfits/CCfits>
#include <QVector4D>
#include "databasedrawgl.h"
#include "drawSpacecraftModel.h"
#include "drawTargetModel.h"
#include "computeelements.h"
#include <QTableWidgetItem>
#include <QProgressBar>
#include "harmonics.h"

using namespace std;
using namespace CCfits;

namespace Ui {
class ObservationDataManagementDBMainWindow;
}

class ObservationDataManagementDBMainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit ObservationDataManagementDBMainWindow(QWidget *parent = 0);
    ~ObservationDataManagementDBMainWindow();

    DatabaseDrawGL *databasedrawgl;
    DrawTargetModel *target;

    QStringList observedTimes;
    QString SCName, SCFrame, targetName, bodyFixed;
    SpiceInt SCID, targetID, instID;
    QString projectDSK;

    QString PLID; 

    int DBRowCount(QString);
    void listUpReadFilesWidget(QStringList);
    SpiceBoolean getImageUTC(QString);
    bool searchPolygonID(QString, SpiceInt, SpiceDLADescr, QString);
    SpiceInt getInstID(QString);
    QString projectName;

signals:
    DrawTargetModel* getTargetModel_signal();
    void sendTargetModel_signal(DrawTargetModel *);
    void setTargetModel_signal();
    void setSearchRegionMode_signal(bool);
    QString getSCName_signal();
    SpiceInt getSCID_singal();
    QString getSCFrame_signal();
    QString getTargetName_signal();
    SpiceInt getTargetID_signal();
    QString getBodyFixed_signal();
    void sendObservedAreas_signal(QStringList);
    void resetRegion_signal();

private slots:
    void on_ReadShapeModel_clicked();

    void on_searchRegionPushButton_clicked(bool checked);

    void setReadFileToDBWindow_slot(QStringList);

    void on_UnloadpushButton_clicked();

    void on_LoadpushButton_clicked();

    void on_MakepushButton_clicked();

    void openDBWindow_slot(QString);

    void on_AddImagesPushButton_clicked();

    void on_projectsTableWidget_clicked(const QModelIndex &index);

    void on_imagesListWidget_clicked(const QModelIndex &index);

    QMap<int, QString> getPLAndImageMap_slot();

    void sendResultSearchImage_slot(QStringList);

    void on_resetRegionButton_clicked();

    void sendLoadKernels_slot(QStringList);

    void on_readFIleListWidget_clicked(const QModelIndex &index);

private:
    Ui::ObservationDataManagementDBMainWindow *ui;

    QSqlQuery query;
    QSqlDatabase DB;

    QStringList readFilesList;

};

int get_cam_info(SpiceInt instid,
                 SpiceDouble center[2],
                 SpiceDouble pixels[2],
                 SpiceDouble *pixel_size,
                 SpiceDouble *focal_length);

#endif

==> fetch.php?media=harmonics%3Aharmonics_2.2.0.zip: HARMONICS2.2.0/HARMONICS/observationdatamanagementdbmainwindow.h <==


//observationdatamanagementdbmainwindow.h
//(c) 2018 The University of Aizu
//This software is released under the GNU General Public License.


#ifndef OBSERVATIONDATAMANAGEMENTDBMAINWINDOW_H
#define OBSERVATIONDATAMANAGEMENTDBMAINWINDOW_H

#include <QMainWindow>
#include <QSqlDatabase>
#include <QSqlDriver>
#include <QSqlQuery>
#include <QSqlError>
#include <QDebug>
#include <QDir>
#include <QFileDialog>
#include <QStandardItemModel>
#include <QAbstractItemModel>
#include <QSqlDatabase>
#include <QSqlQuery>
#include <QSql>
#include <QVector>
#include <QVector2D>
#include "SpiceUsr.h"
#include "SpiceDLA.h"
#include "SpiceDSK.h"
#include <QMenu>
#include <QMessageBox>
#include <QtGui>
#include <fitsio.h>
#ifdef __APPLE__
#include <CCfits>
#else
#include <CCfits/CCfits>
#endif
#include <QVector4D>
#include "databasedrawgl.h"
#include "drawSpacecraftModel.h"
#include "drawTargetModel.h"
#include "computeelements.h"
#include "dbinfomation.h"
#include <QTableWidgetItem>
#include <QProgressBar>
#include "harmonics.h"

using namespace std;
using namespace CCfits;

namespace Ui {
class ObservationDataManagementDBMainWindow;
}

class ObservationDataManagementDBMainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit ObservationDataManagementDBMainWindow(QWidget *parent = 0);
    ~ObservationDataManagementDBMainWindow();

    DatabaseDrawGL *databasedrawgl;
    DrawTargetModel *target;

    DBInfo *DBinfo;

    QStringList observedTimes;
    QString SCName, SCFrame, targetName, bodyFixed;
    QString pixelX, pixelY;
    SpiceInt SCID, targetID, instID;
    QString projectDSK;

    QString PLID;
    int DBRow;

    int DBRowCount(QString);
    void listUpReadFilesWidget(QStringList);
    SpiceBoolean getImageUTC(QString);
    bool searchPolygonID(QString, SpiceInt, SpiceDLADescr, QString);
    SpiceInt getInstID(QString);
    void observedImagesListUp();
    void observedImagesListUp(QStringList);
    void projectsListUp();

    QString projectName;

signals:
    DrawTargetModel* getTargetModel_signal();
    void sendTargetModel_signal(DrawTargetModel *);
    void setTargetModel_signal();
    void setSearchRegionMode_signal(bool);
    QString getSCName_signal();
    SpiceInt getSCID_singal();
    QString getSCFrame_signal();
    QString getTargetName_signal();
    SpiceInt getTargetID_signal();
    QString getBodyFixed_signal();
    void sendObservedAreas_signal(QStringList, bool);
    void resetRegion_signal();
    void setTargetDefaultColor_signal();
    QString getCurrentPath_signal();

private slots:
    void on_searchRegionPushButton_clicked(bool checked);

    void setReadFileToDBWindow_slot(QStringList);

    void on_UnloadpushButton_clicked();

    void on_LoadpushButton_clicked();

    void on_MakepushButton_clicked();

    void openDBWindow_slot(DBInfo *);

    void on_AddImagesPushButton_clicked();

    void on_projectsTableWidget_clicked(const QModelIndex &index);

    void on_imagesListWidget_clicked(const QModelIndex &index);

    QMap<int, QString> getPLAndImageMap_slot();

    void sendResultSearchImage_slot(QStringList);

    void on_resetRegionButton_clicked();

    void setInstrumentsList(QStringList);

    void on_readFIleListWidget_clicked(const QModelIndex &index);

    void on_deleteTable_clicked();

private:
    Ui::ObservationDataManagementDBMainWindow *ui;

    QSqlQuery query;
    QSqlDatabase DB;

    QMap<QString, QString> DBImages;
    QStringList readFilesList;
    QVector<bool> isPolygons;
    SpiceInt projectPolygonNum;

};

int get_cam_info(SpiceInt instid,
                 SpiceDouble center[2],
                 SpiceDouble pixels[2],
                 SpiceDouble *pixel_size,
                 SpiceDouble *focal_length);

#endif
